@@ -78,12 +78,15 @@ void srl_decoder_destructor_hook(pTHX_ void *p);
 #define SRL_F_DECODER_DECOMPRESS_SNAPPY 8UL
 /* Persistent flag: Make the decoder REFUSE compressed documents */
 #define SRL_F_DECODER_REFUSE_SNAPPY 16UL
-/* Persistent flag: Make the decoder REFUSE opjects */
+/* Persistent flag: Make the decoder REFUSE objects */
 #define SRL_F_DECODER_REFUSE_OBJECTS 32UL
 /* Persistent flag: Make the decoder validate UTT8 strings */
 #define SRL_F_DECODER_VALIDATE_UTF8 64UL
 /* Persistent flag: Make the encoder forget to bless */
 #define SRL_F_DECODER_NO_BLESS_OBJECTS 128UL
+/* Persistent flag: Destructive incremental parsing */
+#define SRL_F_DECODER_DESTRUCTIVE_INCREMENTAL 256UL
+
 
 #define SRL_DEC_HAVE_OPTION(dec, flag_num) ((dec)->flags & flag_num)
 #define SRL_DEC_SET_OPTION(dec, flag_num) ((dec)->flags |= flag_num)
